@@ -12,6 +12,7 @@ router = None
 asgi_app = None
 local_lxns_token = None
 local_divingfish_token = None
+local_arcade_proxy = None
 maimai_client = MaimaiClient()
 
 
@@ -77,13 +78,13 @@ if find_spec("fastapi"):
         return DivingFishProvider(token_divingfish or local_divingfish_token)
 
     def dep_arcade():
-        return ArcadeProvider()
+        return ArcadeProvider(http_proxy=local_arcade_proxy)
 
-    def dep_lxns_player(qq: str | None = None, friend_code: int | None = None):
+    def dep_lxns_player(friend_code: int | None = None, qq: str | None = None):
         return PlayerIdentifier(qq=qq, friend_code=friend_code)
 
-    def dep_diving_player(qq: str | None = None, username: str | None = None, credentials: str | None = None):
-        return PlayerIdentifier(qq=qq, username=username, credentials=credentials)
+    def dep_diving_player(username: str | None = None, qq: str | None = None):
+        return PlayerIdentifier(qq=qq, username=username)
 
     def dep_arcade_player(credentials: str):
         return PlayerIdentifier(credentials=credentials)
@@ -122,7 +123,9 @@ if find_spec("fastapi"):
         type_func: Callable[[Song], bool] = lambda song: song.difficulties._get_children(type) != []
         level_func: Callable[[Song], bool] = lambda song: any([diff.level == level for diff in song.difficulties._get_children()])
         versions_func: Callable[[Song], bool] = lambda song: versions.value <= song.version < all_versions[all_versions.index(versions) + 1].value
-        keywords_func: Callable[[Song], bool] = lambda song: keywords.lower() in song.title.lower() + song.artist.lower() + "".join(song.aliases)
+        keywords_func: Callable[[Song], bool] = lambda song: keywords.lower() in song.title.lower() + song.artist.lower() + "".join(
+            alias.lower() for alias in (song.aliases or [])
+        )
         post_conditions = [
             cond for cond, flag in zip([type_func, level_func, versions_func, keywords_func], [type, level, versions, keywords]) if flag
         ]
@@ -336,14 +339,15 @@ if find_spec("fastapi"):
     @router.post(
         "/divingfish/scores",
         tags=["divingfish"],
-        description="Update player scores to Diving Fish",
+        description="Update player scores to Diving Fish, should provide the user's username and password, or import token as credentials.",
     )
     async def update_scores_diving(
         scores: list[Score],
-        player: PlayerIdentifier = Depends(dep_diving_player),
-        provider: DivingFishProvider = Depends(dep_diving),
+        username: str | None = None,
+        credentials: str | None = None,
     ):
-        scores = await maimai_client.updates(player, scores, provider=provider)
+        player = PlayerIdentifier(username=username, credentials=credentials)
+        scores = await maimai_client.updates(player, scores, provider=DivingFishProvider())
 
     @router.get(
         "/lxns/bests",
@@ -444,7 +448,7 @@ if find_spec("fastapi"):
             data=[PlateObjectSimple(song=SongSimple(p.song.id, p.song.title, p.song.artist), levels=p.levels, scores=p.scores) for p in data],
         )
 
-    @router.get("/arcade/regions", response_model=PlayerRegion, tags=["arcade"], description="Get player regions from Arcade")
+    @router.get("/arcade/regions", response_model=list[PlayerRegion], tags=["arcade"], description="Get player regions from Arcade")
     async def get_region(
         player: PlayerIdentifier = Depends(dep_arcade_player),
         provider: ArcadeProvider = Depends(dep_arcade),
@@ -453,7 +457,7 @@ if find_spec("fastapi"):
 
     @router.get("/arcade/qrcode", tags=["arcade"], description="Get encrypted player credentials from QR code")
     async def parse_qrcode(qrcode: str):
-        identifier = await maimai_client.qrcode(qrcode)
+        identifier = await maimai_client.qrcode(qrcode, http_proxy=local_arcade_proxy)
         return {"credentials": identifier.credentials}
 
     @asgi_app.get("/", include_in_schema=False)
