@@ -269,16 +269,22 @@ class Score:
     def _compare(self, other: "Score") -> "Score":
         if other is None:
             return self
-        if self.dx_score and other.dx_score:  # larger value is better
-            return self if self.dx_score > other.dx_score else other
-        if self.achievements and other.achievements and self.achievements != other.achievements:  # larger value is better
-            return self if self.achievements > other.achievements else other
-        if self.rate and other.rate and self.rate != other.rate:  # smaller value is better
-            return self if self.rate.value < other.rate.value else other
-        if (self.fc.value if self.fc else 100) != (other.fc.value if other.fc else 100):  # smaller value is better
-            return self if (self.fc.value if self.fc else 100) < (other.fc.value if other.fc else 100) else other
-        if (self.fs.value if self.fs else 100) != (other.fs.value if other.fs else 100):  # smaller value is better
-            return self if (self.fs.value if self.fs else 100) < (other.fs.value if other.fs else 100) else other
+        if self.dx_score != other.dx_score:  # larger value is better
+            return self if (self.dx_score or 0) > (other.dx_score or 0) else other
+        if self.achievements != other.achievements:  # larger value is better
+            return self if (self.achievements or 0) > (other.achievements or 0) else other
+        if self.rate != other.rate:  # smaller value is better
+            self_rate = self.rate.value if self.rate is not None else 100
+            other_rate = other.rate.value if other.rate is not None else 100
+            return self if self_rate < other_rate else other
+        if self.fc != other.fc:  # smaller value is better
+            self_fc = self.fc.value if self.fc is not None else 100
+            other_fc = other.fc.value if other.fc is not None else 100
+            return self if self_fc < other_fc else other
+        if self.fs != other.fs:  # bigger value is better
+            self_fs = self.fs.value if self.fs is not None else -1
+            other_fs = other.fs.value if other.fs is not None else -1
+            return self if self_fs > other_fs else other
         return self  # we consider they are equal
 
     @property
@@ -374,7 +380,7 @@ class MaimaiSongs:
                     curve_list = curve_list[: len(diffs)]
                 [diffs[i].__setattr__("curve", curve) for i, curve in enumerate(curve_list)]
         for song in self._cached_songs:
-            keywords = song.title.lower() + song.artist.lower() + "".join(song.aliases)
+            keywords = song.title.lower() + song.artist.lower() + "".join(alias.lower() for alias in (song.aliases or []))
             self._keywords_dict[keywords] = song
 
     @staticmethod
@@ -412,6 +418,8 @@ class MaimaiSongs:
         Returns:
             the song if it exists, otherwise return None.
         """
+        if title == "Link(CoF)":
+            return self.by_id(383)
         return next((song for song in self.songs if song.title == title), None)
 
     def by_alias(self, alias: str) -> Song | None:
